Index: trunk/extsrc/gpcsw/gpcsrc/fits/burntool/stardetect.c
===================================================================
--- trunk/extsrc/gpcsw/gpcsrc/fits/burntool/stardetect.c	(revision 42876)
+++ trunk/extsrc/gpcsw/gpcsrc/fits/burntool/stardetect.c	(revision 42877)
@@ -40,7 +40,8 @@
 	thresh_lo = trailthresh;
 
    /*try a new value for burnthresh which is twice the bias above the sky background, but with a safety limit of 30000 counts*/
 	burnthresh = cell->sky + (2*cell->bias);
 	if(burnthresh <= BURN_THRESH) burnthresh = BURN_THRESH;
+	if(burnthresh >= 60000) burnthresh = 60000;
 	thresh_hi = burnthresh;
 
@@ -40,7 +40,8 @@
 	thresh_lo = trailthresh;
 
-   /*try a new value for burnthresh which is twice the bias above the sky background, but with a safety limit of 30000 counts*/
+   /*try a new value for burnthresh which is twice the bias above the sky background, but with a lower safety limit of 30000 counts and upper safety limit of 60000*/
 	burnthresh = cell->sky + (2*cell->bias);
 	if(burnthresh <= BURN_THRESH) burnthresh = BURN_THRESH;
